# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: serve.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import job_pb2 as job__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bserve.proto\x12\x06\x64\x65ploy\x1a\tjob.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfa\x01\n\x07Serving\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\tauth_info\x18\x03 \x01(\x0b\x32\x11.jobs.NBXAuthInfo\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x04type\x18\x05 \x01(\x0e\x32\x1e.deploy.Serving.DeploymentType\x12 \n\x08resource\x18\x06 \x01(\x0b\x32\x0e.jobs.Resource\"/\n\x0e\x44\x65ploymentType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0cNBOX_SERVING\x10\x01\x42\x34Z2github.com/NimbleBoxAI/jobs-architecture/deploy_pbb\x06proto3')



_SERVING = DESCRIPTOR.message_types_by_name['Serving']
_SERVING_DEPLOYMENTTYPE = _SERVING.enum_types_by_name['DeploymentType']
Serving = _reflection.GeneratedProtocolMessageType('Serving', (_message.Message,), {
  'DESCRIPTOR' : _SERVING,
  '__module__' : 'serve_pb2'
  # @@protoc_insertion_point(class_scope:deploy.Serving)
  })
_sym_db.RegisterMessage(Serving)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/NimbleBoxAI/jobs-architecture/deploy_pb'
  _SERVING._serialized_start=68
  _SERVING._serialized_end=318
  _SERVING_DEPLOYMENTTYPE._serialized_start=271
  _SERVING_DEPLOYMENTTYPE._serialized_end=318
# @@protoc_insertion_point(module_scope)



# this file contains code for our AST engine that parses given code, indexes it and then can be queried
# to get things. It's nothing as fancy as SCP, but it will need to have better UX than on_functions.
# Here's a list of usecases till now:
# - find a given object (str) in the given file and return all the relevant information about it

import ast as A
from enum import Enum
from typing import List, Union

class IndexTypes(Enum):
  FUNCTION = A.FunctionDef
  CLASS = A.ClassDef
  VARIABLE = A.Name
  IMPORT = A.Import
  IMPORT_FROM = A.ImportFrom

  def all():
    return [IndexTypes.FUNCTION, IndexTypes.CLASS, IndexTypes.VARIABLE, IndexTypes.IMPORT, IndexTypes.IMPORT_FROM]


class RowItem:
  def __init__(self, name: str, type: IndexTypes, node: A.AST) -> None:
    self.name = name
    self.type = type
    self.node = node


class Visiboi(A.NodeVisitor):
  def __init__(self) -> None:
    self.data = []

  def visit_FunctionDef(self, node: A.FunctionDef) -> None:
    self.data.append(RowItem(node.name, IndexTypes.FUNCTION, node))

  def visit_ClassDef(self, node: A.ClassDef) -> None:
    self.data.append(RowItem(node.name, IndexTypes.CLASS, node))

  def visit_Name(self, node: A.Name) -> None:
    self.data.append(RowItem(node.id, IndexTypes.VARIABLE, node))

  def visit_Import(self, node: A.Import) -> None:
    for n in node.names:
      self.data.append(RowItem(n.name, IndexTypes.IMPORT, node))

  def visit_ImportFrom(self, node: A.ImportFrom) -> None:
    for n in node.names:
      self.data.append(RowItem(n.name, IndexTypes.IMPORT_FROM, node))


class Astea:
  def __init__(self, fname: str) -> None:
    """This is our AST engine, and it works on file level."""
    self.fname = fname
    with open(fname, 'r') as f:
      self.code = f.read()
    self.node = A.parse(self.code)
    self.vis = Visiboi()
    self.vis.visit(self.node)
    self.index = self.vis.data

  def find(self, x: str, types: Union[IndexTypes, List[IndexTypes]] = None) -> list:
    """Find all the instances of x in the file, and return a list of RowItems."""
    if types is None:
      types = IndexTypes.all()
    elif isinstance(types, IndexTypes):
      types = [types]
    return [i for i in self.index if i.name == x and i.type in types]




"""
# NBX-Model

This will combine all the NimbleBox modules into a single callable.
"""

from nbox.operator import Operator

class Model(Operator):
  """Every computation element in the NBX-StratoMembrane is an ``Operator``, thus a model is also just
  a special type of ``Operator``. User will subclass this and wrap their operation specific code in
  the functions"""
  def __init__(self,):
    """Top of the stack Model class."""
    super().__init__()

  def _metadata(self):
    return {"config": "fill _metadata method"}

  def __repr__(self):
    return f"<nbox.Model: {self.model} >"

  def forward(self):
    raise NotImplementedError("Implement your check back later.")

  def load(self, fpath: str):
    # load the model from fpath
    pass

  def save(self, fpath: str):
    # save the model to the fpath
    pass



"""This file contains the code for observability in the networking layer. This is not the same as in case of prometheus
because in our structure the pod is going to be informing the DB about the metrics and not the other way around. We are
chosing this approach because it allows for more flexibility in the future."""

from typing import Tuple
from threading import Lock
import time

try:
  import starlette
  from starlette.requests import Request
  from starlette.responses import Response
  # from starlette.middleware.base import BaseHTTPMiddleware, RequestResponseEndpoint
  from starlette.middleware.base import RequestResponseEndpoint
  from starlette.routing import Match
  from starlette.status import HTTP_500_INTERNAL_SERVER_ERROR
  from starlette.types import ASGIApp
except ImportError:
  starlette = None
  BaseHTTPMiddleware = None


# class GenericMetric:
#   # this is like the prometheus client's Counter, Gauge, Histogram, etc. but instead of client
#   # worrying about the types, here we are saying that it's the servers headache to worry about
#   def __init__(self, name: str, description: str = ""):
#     self.name = name
#     self.description = description
#     self._value = 0
#     self._mutex = Lock()

#   def inc(self, value: int = 1):
#     with self._mutex:
#       self._value += value


# class AsgiLmaoMiddleware():
#   def __init__(self, app, filter_unhandled_paths: bool = False) -> None:
#     if starlette is None:
#       raise ValueError("Starlette is not installed. pip install -U nbox\[serving\]")
#     super().__init__(app)
#     self.filter_unhandled_paths = filter_unhandled_paths

#   async def dispatch(self, request: Request, call_next: RequestResponseEndpoint) -> Response:
#     method = request.method
#     path_template, is_handled_path = self.get_path_template(request)

#     if self._is_path_filtered(is_handled_path):
#       return await call_next(request)

#     REQUESTS_IN_PROGRESS.labels(method = method, path_template = path_template).inc()
#     REQUESTS.labels(method=method, path_template=path_template).inc()
#     before_time = time.perf_counter()
#     try:
#       response = await call_next(request)
#     except BaseException as e:
#       status_code = HTTP_500_INTERNAL_SERVER_ERROR
#       EXCEPTIONS.labels(method=method, path_template=path_template, exception_type=type(e).__name__).inc()
#       raise e from None
#     else:
#       status_code = response.status_code
#       after_time = time.perf_counter()
#       REQUESTS_PROCESSING_TIME.labels(method=method, path_template=path_template).observe(after_time - before_time)
#     finally:
#       RESPONSES.labels(method=method, path_template=path_template, status_code=status_code).inc()
#       REQUESTS_IN_PROGRESS.labels(method=method, path_template=path_template).dec()

#     return response

#   @staticmethod
#   def get_path_template(request: Request) -> Tuple[str, bool]:
#     for route in request.app.routes:
#       match, child_scope = route.matches(request.scope)
#       if match == Match.FULL:
#         return route.path, True
#     return request.url.path, False

#   def _is_path_filtered(self, is_handled_path: bool) -> bool:
#     return self.filter_unhandled_paths and not is_handled_path





# def metrics(request: Request) -> Response:
#   if "prometheus_multiproc_dir" in os.environ:
#     registry = CollectorRegistry()
#     MultiProcessCollector(registry)
#   else:
#     registry = REGISTRY

#   return Response(generate_latest(registry), headers={"Content-Type": CONTENT_TYPE_LATEST})



from starlette_prometheus import metrics, PrometheusMiddleware



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import proto.relics_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class LogBuffer(google.protobuf.message.Message):
    """since this is becoming a more serious thing than what we initially were building we need to make it
    more production ready and the first step is to log a buffer object instead of the individual log object.
    we create a message called LogBuffer which is nothing but an array of _LogObject which in turn is
    either a RunLog or a LiveLog object.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AGENT_TOKEN_FIELD_NUMBER: builtins.int
    RUN_LOGS_FIELD_NUMBER: builtins.int
    LIVE_LOGS_FIELD_NUMBER: builtins.int
    agent_token: typing.Text
    """this is like the experiment_id in runs where an agent tries to connect and server gives it a
    one time token with which all the incoming logs will be identified with
    """

    @property
    def run_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RunLog]:
        """this can either contain one or the other"""
        pass
    @property
    def live_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServingHTTPLog]: ...
    def __init__(self,
        *,
        agent_token: typing.Text = ...,
        run_logs: typing.Optional[typing.Iterable[global___RunLog]] = ...,
        live_logs: typing.Optional[typing.Iterable[global___ServingHTTPLog]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_token",b"agent_token","live_logs",b"live_logs","run_logs",b"run_logs"]) -> None: ...
global___LogBuffer = LogBuffer

class ServingHTTPLog(google.protobuf.message.Message):
    """LiveLog is an individual call event which is created by the user agent whenever a certain API is called.
    it contains some basic information as in any other general monitoring solution.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PATH_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    LATENCY_MS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    path: typing.Text
    """the endpoint ie. /api/monitoring/"""

    method: typing.Text
    """the method ie. GET, POST, PUT, DELETE"""

    status_code: builtins.int
    """the status code ie. 200, 404, 500"""

    latency_ms: builtins.float
    """the latency in milli-seconds"""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the timestamp when this event was created"""
        pass
    def __init__(self,
        *,
        path: typing.Text = ...,
        method: typing.Text = ...,
        status_code: builtins.int = ...,
        latency_ms: builtins.float = ...,
        timestamp: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["latency_ms",b"latency_ms","method",b"method","path",b"path","status_code",b"status_code","timestamp",b"timestamp"]) -> None: ...
global___ServingHTTPLog = ServingHTTPLog

class ListDeploymentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    SERVING_ID_OR_NAME_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    serving_id_or_name: typing.Text
    """used specifically for searching, if empty, it will return all the projects"""

    page_no: builtins.int
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        serving_id_or_name: typing.Text = ...,
        page_no: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_no",b"page_no","serving_id_or_name",b"serving_id_or_name","workspace_id",b"workspace_id"]) -> None: ...
global___ListDeploymentsRequest = ListDeploymentsRequest

class ListDeploymentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class Serving(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        SERVING_ID_FIELD_NUMBER: builtins.int
        SERVING_NAME_FIELD_NUMBER: builtins.int
        TOTAL_MODELS_FIELD_NUMBER: builtins.int
        serving_id: typing.Text
        """the unique ID for this serving"""

        serving_name: typing.Text
        """the usermodifiable name of the serving"""

        total_models: builtins.int
        """the total number of models in this serving group"""

        def __init__(self,
            *,
            serving_id: typing.Text = ...,
            serving_name: typing.Text = ...,
            total_models: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["serving_id",b"serving_id","serving_name",b"serving_name","total_models",b"total_models"]) -> None: ...

    SERVING_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    @property
    def serving(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListDeploymentsResponse.Serving]: ...
    total_pages: builtins.int
    def __init__(self,
        *,
        serving: typing.Optional[typing.Iterable[global___ListDeploymentsResponse.Serving]] = ...,
        total_pages: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["serving",b"serving","total_pages",b"total_pages"]) -> None: ...
global___ListDeploymentsResponse = ListDeploymentsResponse

class ListServingsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """the workspace this is part of"""

    deployment_id: typing.Text
    """the unique ID for this project"""

    run_id: typing.Text
    """for searching"""

    page_no: builtins.int
    desc: builtins.bool
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        deployment_id: typing.Text = ...,
        run_id: typing.Text = ...,
        page_no: builtins.int = ...,
        desc: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id",b"deployment_id","desc",b"desc","page_no",b"page_no","run_id",b"run_id","workspace_id",b"workspace_id"]) -> None: ...
global___ListServingsRequest = ListServingsRequest

class ListServingsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODEL_IDS_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    @property
    def model_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of runs in this project"""
        pass
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of chart-keys for this run"""
        pass
    @property
    def created_at(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """time when these runs were created"""
        pass
    total_pages: builtins.int
    """the total number of pages"""

    def __init__(self,
        *,
        model_ids: typing.Optional[typing.Iterable[typing.Text]] = ...,
        keys: typing.Optional[typing.Iterable[typing.Text]] = ...,
        created_at: typing.Optional[typing.Iterable[builtins.int]] = ...,
        total_pages: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at",b"created_at","keys",b"keys","model_ids",b"model_ids","total_pages",b"total_pages"]) -> None: ...
global___ListServingsResponse = ListServingsResponse

class Serving(google.protobuf.message.Message):
    """the Big Serving Object"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Status:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Serving._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NOT_SET: Serving._Status.ValueType  # 0
        """When created and added to DB but no further action taken"""

        RUNNING: Serving._Status.ValueType  # 1
        """When the first on_serving_log has been called"""

        COMPLETED: Serving._Status.ValueType  # 2
        """When there is a graceful exit on_serving_end has been called"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        pass

    NOT_SET: Serving.Status.ValueType  # 0
    """When created and added to DB but no further action taken"""

    RUNNING: Serving.Status.ValueType  # 1
    """When the first on_serving_log has been called"""

    COMPLETED: Serving.Status.ValueType  # 2
    """When there is a graceful exit on_serving_end has been called"""


    AGENT_FIELD_NUMBER: builtins.int
    AGENT_TOKEN_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    @property
    def agent(self) -> global___AgentDetails:
        """the agent details"""
        pass
    agent_token: typing.Text
    """the unique ID of this agent from the MongoDB backend"""

    created_at: builtins.int
    """same as InitRunRequest.created_at"""

    config: typing.Text
    """the jsonified config string"""

    status: global___Serving.Status.ValueType
    """the last known status of this run"""

    updated_at: builtins.int
    """the last time this"""

    def __init__(self,
        *,
        agent: typing.Optional[global___AgentDetails] = ...,
        agent_token: typing.Text = ...,
        created_at: builtins.int = ...,
        config: typing.Text = ...,
        status: global___Serving.Status.ValueType = ...,
        updated_at: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent",b"agent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent",b"agent","agent_token",b"agent_token","config",b"config","created_at",b"created_at","status",b"status","updated_at",b"updated_at"]) -> None: ...
global___Serving = Serving

class Record(google.protobuf.message.Message):
    """This is the data that the user will be logging if this"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _DataType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _DataTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Record._DataType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FLOAT: Record._DataType.ValueType  # 0
        INTEGER: Record._DataType.ValueType  # 1
        STRING: Record._DataType.ValueType  # 2
    class DataType(_DataType, metaclass=_DataTypeEnumTypeWrapper):
        """since it is not possible to have the map in the message, we need to have an enum for the target datatype"""
        pass

    FLOAT: Record.DataType.ValueType  # 0
    INTEGER: Record.DataType.ValueType  # 1
    STRING: Record.DataType.ValueType  # 2

    KEY_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    FLOAT_DATA_FIELD_NUMBER: builtins.int
    INTEGER_DATA_FIELD_NUMBER: builtins.int
    STRING_DATA_FIELD_NUMBER: builtins.int
    key: typing.Text
    """name of this data"""

    value_type: global___Record.DataType.ValueType
    step: builtins.int
    """also can be called "X-axis" or just x"""

    @property
    def float_data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """all the data is done in the"""
        pass
    @property
    def integer_data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def string_data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        key: typing.Text = ...,
        value_type: global___Record.DataType.ValueType = ...,
        step: builtins.int = ...,
        float_data: typing.Optional[typing.Iterable[builtins.float]] = ...,
        integer_data: typing.Optional[typing.Iterable[builtins.int]] = ...,
        string_data: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["float_data",b"float_data","integer_data",b"integer_data","key",b"key","step",b"step","string_data",b"string_data","value_type",b"value_type"]) -> None: ...
global___Record = Record

class RecordColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _DataType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _DataTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RecordColumn._DataType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FLOAT: RecordColumn._DataType.ValueType  # 0
        INTEGER: RecordColumn._DataType.ValueType  # 1
        STRING: RecordColumn._DataType.ValueType  # 2
    class DataType(_DataType, metaclass=_DataTypeEnumTypeWrapper):
        """type of this data"""
        pass

    FLOAT: RecordColumn.DataType.ValueType  # 0
    INTEGER: RecordColumn.DataType.ValueType  # 1
    STRING: RecordColumn.DataType.ValueType  # 2

    class RecordRow(google.protobuf.message.Message):
        """the actual data"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        X_FIELD_NUMBER: builtins.int
        FLOAT_DATA_FIELD_NUMBER: builtins.int
        INTEGER_DATA_FIELD_NUMBER: builtins.int
        STRING_DATA_FIELD_NUMBER: builtins.int
        x: builtins.int
        """also can be called "X-axis" or just x"""

        float_data: builtins.float
        """all the data is done in the"""

        integer_data: builtins.int
        string_data: typing.Text
        def __init__(self,
            *,
            x: builtins.int = ...,
            float_data: builtins.float = ...,
            integer_data: builtins.int = ...,
            string_data: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["float_data",b"float_data","integer_data",b"integer_data","string_data",b"string_data","x",b"x"]) -> None: ...

    KEY_FIELD_NUMBER: builtins.int
    VALUE_TYPE_FIELD_NUMBER: builtins.int
    ROWS_FIELD_NUMBER: builtins.int
    key: typing.Text
    """since it is not possible to have the map in the message, we need to have an enum for the target datatype
    name of this data
    """

    value_type: global___RecordColumn.DataType.ValueType
    @property
    def rows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordColumn.RecordRow]: ...
    def __init__(self,
        *,
        key: typing.Text = ...,
        value_type: global___RecordColumn.DataType.ValueType = ...,
        rows: typing.Optional[typing.Iterable[global___RecordColumn.RecordRow]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key",b"key","rows",b"rows","value_type",b"value_type"]) -> None: ...
global___RecordColumn = RecordColumn

class RunLog(google.protobuf.message.Message):
    """This is the aggregation of all the logs for this run"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _LogType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _LogTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RunLog._LogType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SYSTEM: RunLog._LogType.ValueType  # 0
        """these are the mtrics like GPU/RAM utilisation"""

        NBX: RunLog._LogType.ValueType  # 1
        """these are the metrics that NimbleBox generates for the user"""

        USER: RunLog._LogType.ValueType  # 2
        """these are the metrics that the user has logged"""

    class LogType(_LogType, metaclass=_LogTypeEnumTypeWrapper):
        pass

    SYSTEM: RunLog.LogType.ValueType  # 0
    """these are the mtrics like GPU/RAM utilisation"""

    NBX: RunLog.LogType.ValueType  # 1
    """these are the metrics that NimbleBox generates for the user"""

    USER: RunLog.LogType.ValueType  # 2
    """these are the metrics that the user has logged"""


    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    COLUMN_DATA_FIELD_NUMBER: builtins.int
    LOG_TYPE_FIELD_NUMBER: builtins.int
    experiment_id: typing.Text
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Record]: ...
    @property
    def column_data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordColumn]:
        """this is the chart wise data"""
        pass
    log_type: global___RunLog.LogType.ValueType
    """type of data"""

    def __init__(self,
        *,
        experiment_id: typing.Text = ...,
        data: typing.Optional[typing.Iterable[global___Record]] = ...,
        column_data: typing.Optional[typing.Iterable[global___RecordColumn]] = ...,
        log_type: global___RunLog.LogType.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_data",b"column_data","data",b"data","experiment_id",b"experiment_id","log_type",b"log_type"]) -> None: ...
global___RunLog = RunLog

class AgentDetails(google.protobuf.message.Message):
    """all the NBX-Infra details for this specific run"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _NBX:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _NBXEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AgentDetails._NBX.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        JOB: AgentDetails._NBX.ValueType  # 0
        SERVING: AgentDetails._NBX.ValueType  # 1
    class NBX(_NBX, metaclass=_NBXEnumTypeWrapper):
        pass

    JOB: AgentDetails.NBX.ValueType  # 0
    SERVING: AgentDetails.NBX.ValueType  # 1

    TYPE_FIELD_NUMBER: builtins.int
    NBX_JOB_ID_FIELD_NUMBER: builtins.int
    NBX_SERVING_ID_FIELD_NUMBER: builtins.int
    NBX_RUN_ID_FIELD_NUMBER: builtins.int
    NBX_MODEL_ID_FIELD_NUMBER: builtins.int
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    type: global___AgentDetails.NBX.ValueType
    """this is the type of the agent, JOB or SERVING"""

    nbx_job_id: typing.Text
    """NBX-Jobs ID"""

    nbx_serving_id: typing.Text
    """deployment id"""

    nbx_run_id: typing.Text
    """JobRun"""

    nbx_model_id: typing.Text
    """model id"""

    workspace_id: typing.Text
    def __init__(self,
        *,
        type: global___AgentDetails.NBX.ValueType = ...,
        nbx_job_id: typing.Text = ...,
        nbx_serving_id: typing.Text = ...,
        nbx_run_id: typing.Text = ...,
        nbx_model_id: typing.Text = ...,
        workspace_id: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["id",b"id","instance",b"instance","nbx_job_id",b"nbx_job_id","nbx_model_id",b"nbx_model_id","nbx_run_id",b"nbx_run_id","nbx_serving_id",b"nbx_serving_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","instance",b"instance","nbx_job_id",b"nbx_job_id","nbx_model_id",b"nbx_model_id","nbx_run_id",b"nbx_run_id","nbx_serving_id",b"nbx_serving_id","type",b"type","workspace_id",b"workspace_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["id",b"id"]) -> typing.Optional[typing_extensions.Literal["nbx_job_id","nbx_serving_id"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["instance",b"instance"]) -> typing.Optional[typing_extensions.Literal["nbx_run_id","nbx_model_id"]]: ...
global___AgentDetails = AgentDetails

class InitRunRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AGENT_DETAILS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    @property
    def agent_details(self) -> global___AgentDetails: ...
    created_at: builtins.int
    """the unix timestamp when this run was created"""

    config: typing.Text
    """the jsonified singular config string"""

    project_id: typing.Text
    """when this is an experiment we will have project details"""

    project_name: typing.Text
    def __init__(self,
        *,
        agent_details: typing.Optional[global___AgentDetails] = ...,
        created_at: builtins.int = ...,
        config: typing.Text = ...,
        project_id: typing.Text = ...,
        project_name: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent_details",b"agent_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_details",b"agent_details","config",b"config","created_at",b"created_at","project_id",b"project_id","project_name",b"project_name"]) -> None: ...
global___InitRunRequest = InitRunRequest

class File(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    IS_INPUT_FIELD_NUMBER: builtins.int
    RELIC_FILE_FIELD_NUMBER: builtins.int
    name: typing.Text
    """the relative (to **job root**) filename of the File, final location is save_location/name"""

    created_at: builtins.int
    """when was this made"""

    is_input: builtins.bool
    """this was there when the run was created or this was created by the run as an output"""

    @property
    def relic_file(self) -> proto.relics_pb2.RelicFile:
        """this is the file when used with"""
        pass
    def __init__(self,
        *,
        name: typing.Text = ...,
        created_at: builtins.int = ...,
        is_input: builtins.bool = ...,
        relic_file: typing.Optional[proto.relics_pb2.RelicFile] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relic_file",b"relic_file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at",b"created_at","is_input",b"is_input","name",b"name","relic_file",b"relic_file"]) -> None: ...
global___File = File

class FileList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    experiment_id: typing.Text
    """associated run"""

    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """all the Files"""
        pass
    def __init__(self,
        *,
        experiment_id: typing.Text = ...,
        files: typing.Optional[typing.Iterable[global___File]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["experiment_id",b"experiment_id","files",b"files"]) -> None: ...
global___FileList = FileList

class Run(google.protobuf.message.Message):
    """the Big Object"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Status:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Run._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NOT_SET: Run._Status.ValueType  # 0
        """When created and added to DB but no further action taken"""

        RUNNING: Run._Status.ValueType  # 1
        """When the first on_log has been called"""

        COMPLETED: Run._Status.ValueType  # 2
        """When the on_train_end has been called"""

        FAILED: Run._Status.ValueType  # 3
        """When the NBX-Job failed"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        pass

    NOT_SET: Run.Status.ValueType  # 0
    """When created and added to DB but no further action taken"""

    RUNNING: Run.Status.ValueType  # 1
    """When the first on_log has been called"""

    COMPLETED: Run.Status.ValueType  # 2
    """When the on_train_end has been called"""

    FAILED: Run.Status.ValueType  # 3
    """When the NBX-Job failed"""


    AGENT_FIELD_NUMBER: builtins.int
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    ENDED_AT_FIELD_NUMBER: builtins.int
    COMPLETED_FIELD_NUMBER: builtins.int
    SAVE_LOCATION_FIELD_NUMBER: builtins.int
    FILE_LIST_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    @property
    def agent(self) -> global___AgentDetails:
        """the agent details"""
        pass
    experiment_id: typing.Text
    """the unique ID of this run from the MongoDB backend"""

    created_at: builtins.int
    """same as InitRunRequest.created_at"""

    ended_at: builtins.int
    """when was run declared dead, the actual kill can be well before that"""

    completed: builtins.bool
    """is this run complete"""

    save_location: typing.Text
    """this is the location where the Files from this run are stored"""

    @property
    def file_list(self) -> global___FileList:
        """all the Files from this run"""
        pass
    config: typing.Text
    """the jsonified config string"""

    status: global___Run.Status.ValueType
    """the last known status of this run"""

    updated_at: builtins.int
    """the last time this run was updated"""

    def __init__(self,
        *,
        agent: typing.Optional[global___AgentDetails] = ...,
        experiment_id: typing.Text = ...,
        created_at: builtins.int = ...,
        ended_at: builtins.int = ...,
        completed: builtins.bool = ...,
        save_location: typing.Text = ...,
        file_list: typing.Optional[global___FileList] = ...,
        config: typing.Text = ...,
        status: global___Run.Status.ValueType = ...,
        updated_at: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent",b"agent","file_list",b"file_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent",b"agent","completed",b"completed","config",b"config","created_at",b"created_at","ended_at",b"ended_at","experiment_id",b"experiment_id","file_list",b"file_list","save_location",b"save_location","status",b"status","updated_at",b"updated_at"]) -> None: ...
global___Run = Run

class ListProjectsRequest(google.protobuf.message.Message):
    """
    Now we have the data structures for the user-client to get the data from the Konark.

    Request Reponse kind of thing
    $app/monitoring/
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_OR_NAME_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """the workspace this is part of"""

    project_id_or_name: typing.Text
    """used specifically for searching, if empty, it will return all the projects"""

    page_no: builtins.int
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id_or_name: typing.Text = ...,
        page_no: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_no",b"page_no","project_id_or_name",b"project_id_or_name","workspace_id",b"workspace_id"]) -> None: ...
global___ListProjectsRequest = ListProjectsRequest

class ListProjectsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class Project(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        PROJECT_ID_FIELD_NUMBER: builtins.int
        PROJECT_NAME_FIELD_NUMBER: builtins.int
        TOTAL_EXPERIMENTS_FIELD_NUMBER: builtins.int
        project_id: typing.Text
        """the unique ID for this project"""

        project_name: typing.Text
        """the usermodifiable name of the project"""

        total_experiments: builtins.int
        """the total number of experiments in this project"""

        def __init__(self,
            *,
            project_id: typing.Text = ...,
            project_name: typing.Text = ...,
            total_experiments: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["project_id",b"project_id","project_name",b"project_name","total_experiments",b"total_experiments"]) -> None: ...

    PROJECTS_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    @property
    def projects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListProjectsResponse.Project]:
        """the list of projects in this workspace"""
        pass
    total_pages: builtins.int
    """the total number of pages"""

    def __init__(self,
        *,
        projects: typing.Optional[typing.Iterable[global___ListProjectsResponse.Project]] = ...,
        total_pages: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["projects",b"projects","total_pages",b"total_pages"]) -> None: ...
global___ListProjectsResponse = ListProjectsResponse

class ListRunsRequest(google.protobuf.message.Message):
    """$app/monitoring/gjj9dk30"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_NO_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    workspace_id: typing.Text
    """the workspace this is part of"""

    project_id: typing.Text
    """the unique ID for this project"""

    experiment_id: typing.Text
    """for searching"""

    page_no: builtins.int
    desc: builtins.bool
    def __init__(self,
        *,
        workspace_id: typing.Text = ...,
        project_id: typing.Text = ...,
        experiment_id: typing.Text = ...,
        page_no: builtins.int = ...,
        desc: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","experiment_id",b"experiment_id","page_no",b"page_no","project_id",b"project_id","workspace_id",b"workspace_id"]) -> None: ...
global___ListRunsRequest = ListRunsRequest

class ListRunsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXPERIMENT_IDS_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    TOTAL_PAGES_FIELD_NUMBER: builtins.int
    @property
    def experiment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of runs in this project"""
        pass
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """the list of chart-keys for this run"""
        pass
    @property
    def created_at(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """time when these runs were created"""
        pass
    total_pages: builtins.int
    """the total number of pages"""

    def __init__(self,
        *,
        experiment_ids: typing.Optional[typing.Iterable[typing.Text]] = ...,
        keys: typing.Optional[typing.Iterable[typing.Text]] = ...,
        created_at: typing.Optional[typing.Iterable[builtins.int]] = ...,
        total_pages: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at",b"created_at","experiment_ids",b"experiment_ids","keys",b"keys","total_pages",b"total_pages"]) -> None: ...
global___ListRunsResponse = ListRunsResponse

class RunLogRequest(google.protobuf.message.Message):
    """logs for $app/monitoring/gjj9dk30/experiment/cmk03kt03/"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXPERIMENT_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    SAMPLE_FIELD_NUMBER: builtins.int
    START_AT_FIELD_NUMBER: builtins.int
    END_AT_FIELD_NUMBER: builtins.int
    experiment_id: typing.Text
    """the unique ID for this run"""

    key: typing.Text
    """the key to search for, if empty, it will return all the logs"""

    sample: builtins.int
    """the number of items to sample, default is 1500"""

    start_at: builtins.int
    """the start at, default is 0"""

    end_at: builtins.int
    """the end at, default is -1"""

    def __init__(self,
        *,
        experiment_id: typing.Text = ...,
        key: typing.Text = ...,
        sample: builtins.int = ...,
        start_at: builtins.int = ...,
        end_at: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_at",b"end_at","experiment_id",b"experiment_id","key",b"key","sample",b"sample","start_at",b"start_at"]) -> None: ...
global___RunLogRequest = RunLogRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/lmao.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nbox.sublime.proto import relics_pb2 as proto_dot_relics__pb2
from nbox.sublime.proto import common_pb2 as proto_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10proto/lmao.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12proto/relics.proto\x1a\x12proto/common.proto\"_\n\tLogBuffer\x12\x13\n\x0b\x61gent_token\x18\x01 \x01(\t\x12\x19\n\x08run_logs\x18\x02 \x03(\x0b\x32\x07.RunLog\x12\"\n\tlive_logs\x18\x03 \x03(\x0b\x32\x0f.ServingHTTPLog\"\x86\x01\n\x0eServingHTTPLog\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x13\n\x0bstatus_code\x18\x03 \x01(\x05\x12\x12\n\nlatency_ms\x18\x04 \x01(\x02\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"[\n\x16ListDeploymentsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x1a\n\x12serving_id_or_name\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\"\xac\x01\n\x17ListDeploymentsResponse\x12\x31\n\x07serving\x18\x01 \x03(\x0b\x32 .ListDeploymentsResponse.Serving\x12\x13\n\x0btotal_pages\x18\x02 \x01(\x05\x1aI\n\x07Serving\x12\x12\n\nserving_id\x18\x01 \x01(\t\x12\x14\n\x0cserving_name\x18\x02 \x01(\t\x12\x14\n\x0ctotal_models\x18\x03 \x01(\x05\"q\n\x13ListServingsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x0f\n\x07page_no\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\x08\"`\n\x14ListServingsResponse\x12\x11\n\tmodel_ids\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x12\n\ncreated_at\x18\x03 \x03(\x03\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\"\xc8\x01\n\x07Serving\x12\x1c\n\x05\x61gent\x18\x01 \x01(\x0b\x32\r.AgentDetails\x12\x13\n\x0b\x61gent_token\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x12\x0e\n\x06\x63onfig\x18\x08 \x01(\t\x12\x1f\n\x06status\x18\t \x01(\x0e\x32\x0f.Serving.Status\x12\x12\n\nupdated_at\x18\n \x01(\x03\"1\n\x06Status\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCOMPLETED\x10\x02\"\xb8\x01\n\x06Record\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\nvalue_type\x18\x02 \x01(\x0e\x32\x10.Record.DataType\x12\x0c\n\x04step\x18\x03 \x01(\x03\x12\x12\n\nfloat_data\x18\x64 \x03(\x02\x12\x14\n\x0cinteger_data\x18\x65 \x03(\x05\x12\x13\n\x0bstring_data\x18\x66 \x03(\t\".\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\n\n\x06STRING\x10\x02\"\xf5\x01\n\x0cRecordColumn\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\nvalue_type\x18\x02 \x01(\x0e\x32\x16.RecordColumn.DataType\x12%\n\x04rows\x18\x03 \x03(\x0b\x32\x17.RecordColumn.RecordRow\x1aU\n\tRecordRow\x12\t\n\x01x\x18\x01 \x01(\x03\x12\x12\n\nfloat_data\x18\x64 \x01(\x02\x12\x14\n\x0cinteger_data\x18\x65 \x01(\x05\x12\x13\n\x0bstring_data\x18\x66 \x01(\t\".\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\n\n\x06STRING\x10\x02\"\xa7\x01\n\x06RunLog\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x15\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x07.Record\x12\"\n\x0b\x63olumn_data\x18\x03 \x03(\x0b\x32\r.RecordColumn\x12!\n\x08log_type\x18\x04 \x01(\x0e\x32\x0f.RunLog.LogType\"(\n\x07LogType\x12\n\n\x06SYSTEM\x10\x00\x12\x07\n\x03NBX\x10\x01\x12\x08\n\x04USER\x10\x02\"\xd2\x01\n\x0c\x41gentDetails\x12\x1f\n\x04type\x18\x06 \x01(\x0e\x32\x11.AgentDetails.NBX\x12\x14\n\nnbx_job_id\x18\x01 \x01(\tH\x00\x12\x18\n\x0enbx_serving_id\x18\x03 \x01(\tH\x00\x12\x14\n\nnbx_run_id\x18\x02 \x01(\tH\x01\x12\x16\n\x0cnbx_model_id\x18\x04 \x01(\tH\x01\x12\x14\n\x0cworkspace_id\x18\x05 \x01(\t\"\x1b\n\x03NBX\x12\x07\n\x03JOB\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x42\x04\n\x02idB\n\n\x08instance\"\x84\x01\n\x0eInitRunRequest\x12$\n\ragent_details\x18\x01 \x01(\x0b\x32\r.AgentDetails\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x12\x0e\n\x06\x63onfig\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x05 \x01(\t\"Z\n\x04\x46ile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\x03\x12\x10\n\x08is_input\x18\x03 \x01(\x08\x12\x1e\n\nrelic_file\x18\x04 \x01(\x0b\x32\n.RelicFile\"7\n\x08\x46ileList\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x14\n\x05\x66iles\x18\x02 \x03(\x0b\x32\x05.File\"\xa8\x02\n\x03Run\x12\x1c\n\x05\x61gent\x18\x01 \x01(\x0b\x32\r.AgentDetails\x12\x15\n\rexperiment_id\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x12\x10\n\x08\x65nded_at\x18\x04 \x01(\x03\x12\x11\n\tcompleted\x18\x05 \x01(\x08\x12\x15\n\rsave_location\x18\x06 \x01(\t\x12\x1c\n\tfile_list\x18\x07 \x01(\x0b\x32\t.FileList\x12\x0e\n\x06\x63onfig\x18\x08 \x01(\t\x12\x1b\n\x06status\x18\t \x01(\x0e\x32\x0b.Run.Status\x12\x12\n\nupdated_at\x18\n \x01(\x03\"=\n\x06Status\x12\x0b\n\x07NOT_SET\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\r\n\tCOMPLETED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\"X\n\x13ListProjectsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x1a\n\x12project_id_or_name\x18\x02 \x01(\t\x12\x0f\n\x07page_no\x18\x03 \x01(\x05\"\xac\x01\n\x14ListProjectsResponse\x12/\n\x08projects\x18\x01 \x03(\x0b\x32\x1d.ListProjectsResponse.Project\x12\x13\n\x0btotal_pages\x18\x02 \x01(\x05\x1aN\n\x07Project\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0cproject_name\x18\x02 \x01(\t\x12\x19\n\x11total_experiments\x18\x03 \x01(\x05\"q\n\x0fListRunsRequest\x12\x14\n\x0cworkspace_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0f\n\x07page_no\x18\x04 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\x08\"a\n\x10ListRunsResponse\x12\x16\n\x0e\x65xperiment_ids\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x12\n\ncreated_at\x18\x03 \x03(\x03\x12\x13\n\x0btotal_pages\x18\x04 \x01(\x05\"e\n\rRunLogRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06sample\x18\x03 \x01(\x05\x12\x10\n\x08start_at\x18\x04 \x01(\x05\x12\x0e\n\x06\x65nd_at\x18\x05 \x01(\x05\x32\x8d\x06\n\x04LMAO\x12#\n\x08init_run\x12\x0f.InitRunRequest\x1a\x04.Run\"\x00\x12)\n\x11update_run_status\x12\x04.Run\x1a\x0c.Acknowledge\"\x00\x12!\n\x06on_log\x12\x07.RunLog\x1a\x0c.Acknowledge\"\x00\x12$\n\x07on_save\x12\t.FileList\x1a\x0c.Acknowledge\"\x00\x12$\n\x0con_train_end\x12\x04.Run\x1a\x0c.Acknowledge\"\x00\x12>\n\rlist_projects\x12\x14.ListProjectsRequest\x1a\x15.ListProjectsResponse\"\x00\x12\x32\n\tlist_runs\x12\x10.ListRunsRequest\x1a\x11.ListRunsResponse\"\x00\x12\x1f\n\x0fget_run_details\x12\x04.Run\x1a\x04.Run\"\x00\x12(\n\x0bget_run_log\x12\x0e.RunLogRequest\x1a\x07.RunLog\"\x00\x12\x1f\n\nlist_files\x12\x04.Run\x1a\t.FileList\"\x00\x12+\n\x0cinit_serving\x12\x0f.InitRunRequest\x1a\x08.Serving\"\x00\x12,\n\x0eon_serving_log\x12\n.LogBuffer\x1a\x0c.Acknowledge\"\x00\x12*\n\x0eon_serving_end\x12\x08.Serving\x1a\x0c.Acknowledge\"\x00\x12G\n\x10list_deployments\x12\x17.ListDeploymentsRequest\x1a\x18.ListDeploymentsResponse\"\x00\x12>\n\rlist_servings\x12\x14.ListServingsRequest\x1a\x15.ListServingsResponse\"\x00\x12+\n\x13get_serving_details\x12\x08.Serving\x1a\x08.Serving\"\x00\x12)\n\x0fget_serving_log\x12\x08.Serving\x1a\n.LogBuffer\"\x00\x62\x06proto3')



_LOGBUFFER = DESCRIPTOR.message_types_by_name['LogBuffer']
_SERVINGHTTPLOG = DESCRIPTOR.message_types_by_name['ServingHTTPLog']
_LISTDEPLOYMENTSREQUEST = DESCRIPTOR.message_types_by_name['ListDeploymentsRequest']
_LISTDEPLOYMENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListDeploymentsResponse']
_LISTDEPLOYMENTSRESPONSE_SERVING = _LISTDEPLOYMENTSRESPONSE.nested_types_by_name['Serving']
_LISTSERVINGSREQUEST = DESCRIPTOR.message_types_by_name['ListServingsRequest']
_LISTSERVINGSRESPONSE = DESCRIPTOR.message_types_by_name['ListServingsResponse']
_SERVING = DESCRIPTOR.message_types_by_name['Serving']
_RECORD = DESCRIPTOR.message_types_by_name['Record']
_RECORDCOLUMN = DESCRIPTOR.message_types_by_name['RecordColumn']
_RECORDCOLUMN_RECORDROW = _RECORDCOLUMN.nested_types_by_name['RecordRow']
_RUNLOG = DESCRIPTOR.message_types_by_name['RunLog']
_AGENTDETAILS = DESCRIPTOR.message_types_by_name['AgentDetails']
_INITRUNREQUEST = DESCRIPTOR.message_types_by_name['InitRunRequest']
_FILE = DESCRIPTOR.message_types_by_name['File']
_FILELIST = DESCRIPTOR.message_types_by_name['FileList']
_RUN = DESCRIPTOR.message_types_by_name['Run']
_LISTPROJECTSREQUEST = DESCRIPTOR.message_types_by_name['ListProjectsRequest']
_LISTPROJECTSRESPONSE = DESCRIPTOR.message_types_by_name['ListProjectsResponse']
_LISTPROJECTSRESPONSE_PROJECT = _LISTPROJECTSRESPONSE.nested_types_by_name['Project']
_LISTRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListRunsRequest']
_LISTRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListRunsResponse']
_RUNLOGREQUEST = DESCRIPTOR.message_types_by_name['RunLogRequest']
_SERVING_STATUS = _SERVING.enum_types_by_name['Status']
_RECORD_DATATYPE = _RECORD.enum_types_by_name['DataType']
_RECORDCOLUMN_DATATYPE = _RECORDCOLUMN.enum_types_by_name['DataType']
_RUNLOG_LOGTYPE = _RUNLOG.enum_types_by_name['LogType']
_AGENTDETAILS_NBX = _AGENTDETAILS.enum_types_by_name['NBX']
_RUN_STATUS = _RUN.enum_types_by_name['Status']
LogBuffer = _reflection.GeneratedProtocolMessageType('LogBuffer', (_message.Message,), {
  'DESCRIPTOR' : _LOGBUFFER,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:LogBuffer)
  })
_sym_db.RegisterMessage(LogBuffer)

ServingHTTPLog = _reflection.GeneratedProtocolMessageType('ServingHTTPLog', (_message.Message,), {
  'DESCRIPTOR' : _SERVINGHTTPLOG,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ServingHTTPLog)
  })
_sym_db.RegisterMessage(ServingHTTPLog)

ListDeploymentsRequest = _reflection.GeneratedProtocolMessageType('ListDeploymentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYMENTSREQUEST,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ListDeploymentsRequest)
  })
_sym_db.RegisterMessage(ListDeploymentsRequest)

ListDeploymentsResponse = _reflection.GeneratedProtocolMessageType('ListDeploymentsResponse', (_message.Message,), {

  'Serving' : _reflection.GeneratedProtocolMessageType('Serving', (_message.Message,), {
    'DESCRIPTOR' : _LISTDEPLOYMENTSRESPONSE_SERVING,
    '__module__' : 'proto.lmao_pb2'
    # @@protoc_insertion_point(class_scope:ListDeploymentsResponse.Serving)
    })
  ,
  'DESCRIPTOR' : _LISTDEPLOYMENTSRESPONSE,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ListDeploymentsResponse)
  })
_sym_db.RegisterMessage(ListDeploymentsResponse)
_sym_db.RegisterMessage(ListDeploymentsResponse.Serving)

ListServingsRequest = _reflection.GeneratedProtocolMessageType('ListServingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSREQUEST,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ListServingsRequest)
  })
_sym_db.RegisterMessage(ListServingsRequest)

ListServingsResponse = _reflection.GeneratedProtocolMessageType('ListServingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSRESPONSE,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ListServingsResponse)
  })
_sym_db.RegisterMessage(ListServingsResponse)

Serving = _reflection.GeneratedProtocolMessageType('Serving', (_message.Message,), {
  'DESCRIPTOR' : _SERVING,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:Serving)
  })
_sym_db.RegisterMessage(Serving)

Record = _reflection.GeneratedProtocolMessageType('Record', (_message.Message,), {
  'DESCRIPTOR' : _RECORD,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:Record)
  })
_sym_db.RegisterMessage(Record)

RecordColumn = _reflection.GeneratedProtocolMessageType('RecordColumn', (_message.Message,), {

  'RecordRow' : _reflection.GeneratedProtocolMessageType('RecordRow', (_message.Message,), {
    'DESCRIPTOR' : _RECORDCOLUMN_RECORDROW,
    '__module__' : 'proto.lmao_pb2'
    # @@protoc_insertion_point(class_scope:RecordColumn.RecordRow)
    })
  ,
  'DESCRIPTOR' : _RECORDCOLUMN,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:RecordColumn)
  })
_sym_db.RegisterMessage(RecordColumn)
_sym_db.RegisterMessage(RecordColumn.RecordRow)

RunLog = _reflection.GeneratedProtocolMessageType('RunLog', (_message.Message,), {
  'DESCRIPTOR' : _RUNLOG,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:RunLog)
  })
_sym_db.RegisterMessage(RunLog)

AgentDetails = _reflection.GeneratedProtocolMessageType('AgentDetails', (_message.Message,), {
  'DESCRIPTOR' : _AGENTDETAILS,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:AgentDetails)
  })
_sym_db.RegisterMessage(AgentDetails)

InitRunRequest = _reflection.GeneratedProtocolMessageType('InitRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITRUNREQUEST,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:InitRunRequest)
  })
_sym_db.RegisterMessage(InitRunRequest)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
  'DESCRIPTOR' : _FILE,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:File)
  })
_sym_db.RegisterMessage(File)

FileList = _reflection.GeneratedProtocolMessageType('FileList', (_message.Message,), {
  'DESCRIPTOR' : _FILELIST,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:FileList)
  })
_sym_db.RegisterMessage(FileList)

Run = _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
  'DESCRIPTOR' : _RUN,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:Run)
  })
_sym_db.RegisterMessage(Run)

ListProjectsRequest = _reflection.GeneratedProtocolMessageType('ListProjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROJECTSREQUEST,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ListProjectsRequest)
  })
_sym_db.RegisterMessage(ListProjectsRequest)

ListProjectsResponse = _reflection.GeneratedProtocolMessageType('ListProjectsResponse', (_message.Message,), {

  'Project' : _reflection.GeneratedProtocolMessageType('Project', (_message.Message,), {
    'DESCRIPTOR' : _LISTPROJECTSRESPONSE_PROJECT,
    '__module__' : 'proto.lmao_pb2'
    # @@protoc_insertion_point(class_scope:ListProjectsResponse.Project)
    })
  ,
  'DESCRIPTOR' : _LISTPROJECTSRESPONSE,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ListProjectsResponse)
  })
_sym_db.RegisterMessage(ListProjectsResponse)
_sym_db.RegisterMessage(ListProjectsResponse.Project)

ListRunsRequest = _reflection.GeneratedProtocolMessageType('ListRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNSREQUEST,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ListRunsRequest)
  })
_sym_db.RegisterMessage(ListRunsRequest)

ListRunsResponse = _reflection.GeneratedProtocolMessageType('ListRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNSRESPONSE,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:ListRunsResponse)
  })
_sym_db.RegisterMessage(ListRunsResponse)

RunLogRequest = _reflection.GeneratedProtocolMessageType('RunLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNLOGREQUEST,
  '__module__' : 'proto.lmao_pb2'
  # @@protoc_insertion_point(class_scope:RunLogRequest)
  })
_sym_db.RegisterMessage(RunLogRequest)

_LMAO = DESCRIPTOR.services_by_name['LMAO']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGBUFFER._serialized_start=93
  _LOGBUFFER._serialized_end=188
  _SERVINGHTTPLOG._serialized_start=191
  _SERVINGHTTPLOG._serialized_end=325
  _LISTDEPLOYMENTSREQUEST._serialized_start=327
  _LISTDEPLOYMENTSREQUEST._serialized_end=418
  _LISTDEPLOYMENTSRESPONSE._serialized_start=421
  _LISTDEPLOYMENTSRESPONSE._serialized_end=593
  _LISTDEPLOYMENTSRESPONSE_SERVING._serialized_start=520
  _LISTDEPLOYMENTSRESPONSE_SERVING._serialized_end=593
  _LISTSERVINGSREQUEST._serialized_start=595
  _LISTSERVINGSREQUEST._serialized_end=708
  _LISTSERVINGSRESPONSE._serialized_start=710
  _LISTSERVINGSRESPONSE._serialized_end=806
  _SERVING._serialized_start=809
  _SERVING._serialized_end=1009
  _SERVING_STATUS._serialized_start=960
  _SERVING_STATUS._serialized_end=1009
  _RECORD._serialized_start=1012
  _RECORD._serialized_end=1196
  _RECORD_DATATYPE._serialized_start=1150
  _RECORD_DATATYPE._serialized_end=1196
  _RECORDCOLUMN._serialized_start=1199
  _RECORDCOLUMN._serialized_end=1444
  _RECORDCOLUMN_RECORDROW._serialized_start=1311
  _RECORDCOLUMN_RECORDROW._serialized_end=1396
  _RECORDCOLUMN_DATATYPE._serialized_start=1150
  _RECORDCOLUMN_DATATYPE._serialized_end=1196
  _RUNLOG._serialized_start=1447
  _RUNLOG._serialized_end=1614
  _RUNLOG_LOGTYPE._serialized_start=1574
  _RUNLOG_LOGTYPE._serialized_end=1614
  _AGENTDETAILS._serialized_start=1617
  _AGENTDETAILS._serialized_end=1827
  _AGENTDETAILS_NBX._serialized_start=1782
  _AGENTDETAILS_NBX._serialized_end=1809
  _INITRUNREQUEST._serialized_start=1830
  _INITRUNREQUEST._serialized_end=1962
  _FILE._serialized_start=1964
  _FILE._serialized_end=2054
  _FILELIST._serialized_start=2056
  _FILELIST._serialized_end=2111
  _RUN._serialized_start=2114
  _RUN._serialized_end=2410
  _RUN_STATUS._serialized_start=2349
  _RUN_STATUS._serialized_end=2410
  _LISTPROJECTSREQUEST._serialized_start=2412
  _LISTPROJECTSREQUEST._serialized_end=2500
  _LISTPROJECTSRESPONSE._serialized_start=2503
  _LISTPROJECTSRESPONSE._serialized_end=2675
  _LISTPROJECTSRESPONSE_PROJECT._serialized_start=2597
  _LISTPROJECTSRESPONSE_PROJECT._serialized_end=2675
  _LISTRUNSREQUEST._serialized_start=2677
  _LISTRUNSREQUEST._serialized_end=2790
  _LISTRUNSRESPONSE._serialized_start=2792
  _LISTRUNSRESPONSE._serialized_end=2889
  _RUNLOGREQUEST._serialized_start=2891
  _RUNLOGREQUEST._serialized_end=2992
  _LMAO._serialized_start=2995
  _LMAO._serialized_end=3776
# @@protoc_insertion_point(module_scope)
